export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/Users/ec2-user/ci_py311/pymongo_1678420613622/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p"
export ARCH="64"
export PREFIX="/Users/ec2-user/ci_py311/pymongo_1678420613622/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p"
export BUILD_PREFIX="/Users/ec2-user/ci_py311/pymongo_1678420613622/_build_env"
export SYS_PREFIX="/usr/local/conda/envs/percy"
export SYS_PYTHON="/usr/local/conda/envs/percy/bin/python"
export SUBDIR="osx-64"
export build_platform="osx-64"
export SRC_DIR="/Users/ec2-user/ci_py311/pymongo_1678420613622/work"
export ROOT="/usr/local/conda/envs/percy"
export CONDA_PY="311"
export PY3K="1"
export PY_VER="3.11"
export STDLIB_DIR="/Users/ec2-user/ci_py311/pymongo_1678420613622/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/lib/python3.11"
export SP_DIR="/Users/ec2-user/ci_py311/pymongo_1678420613622/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/lib/python3.11/site-packages"
export PYTHON="/Users/ec2-user/ci_py311/pymongo_1678420613622/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/bin/python"
export NPY_VER="1.22"
export CONDA_NPY="122"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.34"
export CONDA_PERL="5.34"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="3.5"
export CONDA_R="3.5"
export PKG_NAME="pymongo"
export PKG_VERSION="3.12.0"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/Users/ec2-user/aggregate/pymongo-feedstock/recipe"
export CPU_COUNT="12"
export LANG="en_CA.UTF-8"
export SHLIB_EXT=".dylib"
export PATH="/Users/ec2-user/ci_py311/pymongo_1678420613622/_build_env/bin:/Users/ec2-user/ci_py311/pymongo_1678420613622/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/bin:/usr/local/conda/envs/percy/bin:/usr/local/conda/condabin:/usr/local/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin"
export HOME="/Users/ec2-user"
export PKG_CONFIG_PATH="/Users/ec2-user/ci_py311/pymongo_1678420613622/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export OSX_ARCH="x86_64"
export MACOSX_DEPLOYMENT_TARGET="10.9"
export BUILD="x86_64-apple-darwin13.4.0"
export pin_run_as_build="OrderedDict([('python', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('r-base', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('libboost', {'max_pin': 'x.x.x'})])"
export extend_keys="{'pin_run_as_build', 'ignore_version', 'ignore_build_only_deps', 'extend_keys'}"
export ignore_build_only_deps="{'python', 'numpy'}"
export zip_keys="[['python', 'numpy']]"
export cran_mirror="https://mran.microsoft.com/snapshot/2018-01-01"
export expat="2"
export gst_plugins_base="1.14"
export libgdal="3.0"
export python_impl="cpython"
export CONDA_BUILD_SYSROOT="/opt/MacOSX10.10.sdk"
export hdfeos5="5.1"
export VERBOSE_CM="VERBOSE=1"
export clang_variant="clang"
export macos_machine="x86_64-apple-darwin13.4.0"
export rust_compiler="rust"
export libprotobuf="3.20.3"
export libtiff="4.1"
export openjpeg="2.3"
export libdap4="3.19"
export r_version="3.5.0"
export harfbuzz="4.3.0"
export libgd="2.3.3"
export libkml="1.3"
export c_compiler="clang"
export fortran_compiler_version="11.2.0"
export c_compiler_version="14"
export jpeg="9"
export cxx_compiler="clangxx"
export xz="5"
export boost="1.73"
export glib="2"
export r_implementation="r-base"
export libxslt="1.1"
export dbus="1"
export proj4="5.2.0"
export zstd="1.5.2"
export libnetcdf="4.8"
export cyrus_sasl="2.1.26"
export apr="1.6.3"
export bzip2="1.0"
export proj="6.2.1"
export serf="1.3.9"
export freetype="2.10"
export python_implementation="cpython"
export icu="58"
export openssl="1.1.1"
export libpng="1.6"
export macos_min_version="10.9"
export zlib="1.2"
export boost_cpp="1.73"
export libxml2="2.9"
export libgsasl="1.8"
export libffi="3.4"
export tk="8.6"
export blas_impl="openblas"
export cxx_compiler_version="14"
export readline="8.0"
export cairo="1.16"
export VERBOSE_AT="V=1"
export cpu_optimization_target="nocona"
export giflib="5"
export llvm_variant="llvm"
export libwebp="1.2.0"
export fontconfig="2.14"
export mpfr="4"
export hdfeos2="2.20"
export hdf5="1.10.6"
export gnu="2.12.2"
export hdf4="4.2"
export pixman="0.40"
export sqlite="3"
export channel_targets="defaults"
export gmp="6.1"
export g2clib="1.6"
export r_base="3.5"
export target_platform="osx-64"
export gstreamer="1.14"
export rust_compiler_version="1.56.0"
export fortran_compiler="gfortran"
export lzo="2"
export mkl="2021.*"
export openblas="0.3.20"
export geos="3.8.0"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/Users/ec2-user/ci_py311/pymongo_1678420613622/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/usr/local/conda/envs/percy/bin/python' -m conda shell.bash hook)"
conda activate "/Users/ec2-user/ci_py311/pymongo_1678420613622/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p"
conda activate --stack "/Users/ec2-user/ci_py311/pymongo_1678420613622/_build_env"
